===============
ELLIPTIc MeshQL
===============


.. image:: https://img.shields.io/pypi/v/elliptic_meshql.svg
        :target: https://pypi.python.org/pypi/elliptic_meshql

.. image:: https://img.shields.io/travis/padmec-reservoir/elliptic_meshql.svg
        :target: https://travis-ci.org/padmec-reservoir/elliptic_meshql




ELLIPTIc DSL Contracts for MeshQL.


* Free software: MIT license


Features
--------

* TODO

